
# Dummy Device Driver

This package demonstrates how to develop a device driver that can be integrated with the `cgse` 
framwork. It provides a Dummy Control Server that connects to a Dummy Device that is actually a 
data acquisition simulator.

TBW, more to come later....
